Event

#[non_exhaustive]
pub enum Event { Created { buffer: WlBuffer, }, Failed, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Created

buffer creation succeeded

This event indicates that the attempted buffer creation was successful. It provides the new wl_buffer referencing the dmabuf(s).

Upon receiving this event, the client should destroy the zwp_linux_buffer_params_v1 object.

Fields

buffer: WlBuffer

the newly created wl_buffer



Failed

buffer creation failed

This event indicates that the attempted buffer creation has failed. It usually means that one of the dmabuf constraints has not been fulfilled.

Upon receiving this event, the client should destroy the zwp_linux_buffer_params_v1 object.

Implementations

Source

impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message